function representa(grafActivas, ruta, ptoObsv, nTrama, bitsTrama, ... 
                    tipoVisual, f, color, retardo, actualiza)
%------------------------------------------------------------------------
%|  representa(grafActivas, ruta, ptoObsv, nTrama, bitsTrama, ... 
%|                    tipoVisual, f, color, retardo, actualiza)
%------------------------------------------------------------------------
%|    Funcin que realiza la representacin en pantalla de los ptos.
%|  de Observacin deseados.
%|
%|       NO REALIZA VALIDACIN DE PARMETROS DE ENTRADA
%|
%|    Entradas:
%|       1.- GRAF_ACTIVAS= vector fila de dos elementos.
%|                         [Activa Graf. Sup., Activa Graf. Inf.]
%|       2.- RUTA        = cadena de caracteres la ruta de los ficheros 
%|       3.- PTOS. OBSV  = vector fila de dos elementos 
%|                         [pto.Observacin Sup, pto.Observacin Inf]
%|       4.- N_TRAMA     = entero con el nmero de trama a representar
%|       5.- BITS_TRAMA  = entero con el nmero de bits/trama
%|       6.- TIPO_VISUAL = bandera: 0 = rep. temporal; 1= rep. espectral
%|       7.- F           = vector fila [Rb fi fs].
%|       8.- COLOR       = vector fila [Color Sup, Color Inf]
%|       9.- RETARDO     = vector fila [retardo Graf. Sup; Retardo Graf. Inf.]
%|      10.- ACTUALIZA   = vector fila [actualiza Graf. Sup; actualiza Graf. Inf];
%-------------------------------------------------------------------------
%   Autor: Cesar Delgado
%   Fecha: 19-Abril-2.004
%-------------------------------------------------------------------------

% 1.- REPRESENTACIN EN GRFICA SUPERIOR
%########################################
pUP = 1; pDOWN = 2;

if grafActivas(pUP) & actualiza(pUP),
   
   % 1.1.- Extraemos la seal del pto. de Observacin
   %-------------------------------------------------
   [binarioUp, signalUp] = extraeSignal(ruta, ptoObsv(pUP), ...
                            nTrama, bitsTrama, f, retardo(pUP));
   
   % 1.2.- Representamos la seal en la grfica superior
   %---------------------------------------------------
   dibujaSignal(signalUp, binarioUp, f, grafActivas, ...
               nTrama, tipoVisual(pUP), color(pUP), 1);
   
end;

% 2.- REPRESENTACIN EN GRFICA INFERIOR
%########################################

if grafActivas(pDOWN) & actualiza(pDOWN),
   
   % 2.1.- Extraemos la seal del pto. de Observacin
   %-------------------------------------------------
   [binarioDown, signalDown] = extraeSignal(ruta, ptoObsv(pDOWN), ...
                                            nTrama, bitsTrama, f, retardo(pDOWN));
   
   % 2.2.- Representamos la seal en la grfica inferior
   %---------------------------------------------------
   dibujaSignal(signalDown, binarioDown, f, grafActivas, ...
                nTrama, tipoVisual(pDOWN), color(pDOWN), 0);
end; 

if sum(grafActivas) == 0,
    dibujaSignal(0);
end;



