function [Ebit] = enerBit(signal, L)

%------------------------------------------------------------------------
%|  function Ebit = enerBit(signal, L)
%------------------------------------------------------------------------
%|    Funcion que calcula la energia de bit de una seal digital 
%|  banda base. Devuelve un vector con N valores, correspondientes
%| a la energia de los N bits de entrada
%|  
%|       NO REALIZA VALIDACIN DE PARMETROS DE ENTRADA
%|
%|    Entradas:
%|       1.- SIGNAL = vector fila con la seal digital banda base
%|                    Restricciones: debe tener numero entero de bits
%|       2.- L      = numero de muestras / bit
%-------------------------------------------------------------------------
%   Autor: Cesar Delgado
%   Fecha: 19-Abril-2.004
%-------------------------------------------------------------------------

% 1.- N bits de la secuencia
%----------------------------
lon = length(signal);
nBits = lon/L;

% 2.- Valor medio en cada bit
%-----------------------------
Ebit = reshape(signal./std(signal), L, nBits);
Ebit = (1/L).*sum(Ebit,1);

