function H = filtroHilbert(orden)
%------------------------------------------------------------------------
%|  function H = filtroHilbert(orden)
%------------------------------------------------------------------------
%|    Funcin que devuelve los coeficientes de un filtro que
%|  implementa de Hilbert.
%|    Un filtro de Hilbert es un filtro paso todo
%|   con un retardo de 90 en toda la banda. 
%|     Exiten varios mtodos para implementar dicho filtro,
%|   esta funcin usa el algoritmo REMEZ de Matlab.
%|
%|    Entradas:
%|       1.- ORDEN =  orden del filtro. 
%|                    Restricciones     : n positivo y par
%|                    Valor por defecto : 32
%|
%|   Nota: requiere Toolbox de seales. Para ms informacin "help remez" 
%-------------------------------------------------------------------------
%|   Autor: Cesar Delgado
%|   Fecha: 19-Abril-2.004
%-------------------------------------------------------------------------


%  1.- Validacion de parmetros de entrada
%-----------------------------------------
%     1.1.- Asignamos valores por defecto caso de 
%           omisin
if nargin < 1
   orden = 32;
end;

%     1.2.- Forzamos orden par
orden = abs(2*ceil(orden/2));

% 2.- Diseamos Filtro FIR de Hilbert de fase lineal
%---------------------------------------------------
N = orden + 1;
f = 0.1:0.001:0.901; % Frecuencias donde la fase es lineal
a = ones(length(f)); % Amplitud constante en toda la banda
H = remez(orden, f, a, 'hilbert'); %