function [vco, memoria] = miVCO(error, memoria, fs, Kv)

%------------------------------------------------------------------------
%|  function [vco, memoria] = miVCO(error, memoria, fs, Kv)
%------------------------------------------------------------------------
%|    Funcin que simula la accin de un integrador de fase (VCO dentro 
%|  del lazo de un PLL). De esta forma, el ngulo que se le debe 
%|  aplicar a un tono para estar en fase con la seal de referencia
%|  del PLL.
%|     Se ha empleado la transformacin bilineal para el diseo de 
%|  este filtro IIR.
%|
%|     Est diseada para filtrar una sola muestra y devolver
%|  las condiciones finales. Se debe llamar dentro de un bucle.
%|     Realiza clculos redundantes por motivos de legibilidad de cdigo.
%|  
%|    NO REALIZA VALIDACIN DE LOS PARMETROS DE ENTRADA
%|
%|    Entradas:
%|       1.- ERROR  =  muestra de la seal de entrada.
%|       2.- MEMORIA = vector fila con las condiciones a aplicar
%|       3.- FS  = frecuencia de muestreo
%|       4.- Kv     =  cte. de sensibilidad del VCO [Hz/V]
%|
%|     Salidas:
%|       1.- VCO      = muestra de salida tras el filtrado
%|       2.- MEMORIA  = vector con las cond. finales
%-------------------------------------------------------------------------
%|   Autor: Cesar Delgado
%|   Fecha: 19-Abril-2.004
%-------------------------------------------------------------------------

% 1.- Clculo de la cte. del lazo en funcin
%-------------------------------------------
b = Kv/fs;

% 2.- Filtrado (Forma Directa I)
%-------------------------------
vco     = b*error + memoria(1);
memoria = vco;  
