function [paquete] = entrelaza(datos, filas, columnas)
%------------------------------------------------------------------------
%|  function [paquete] = entrelaza(paquete, filas, columnas)
%------------------------------------------------------------------------
%|    Funcin que entrelaza bloques bloques de 140 bits. 
%|
%|        NO VALIDA PARMETROS DE ENTRADA !!!!!!!!!!!!!
%|
%|    Entradas:
%|       1.- DATOS =  vector fila de, como mximo, 140 bits.
%|                    Si hay ms de 140 bits en datos, se trunca a 140.
%|       2.- FILAS = filas de la matriz de entrelazado
%|                   Valor por defecto: 14
%|                   Restricciones: filas x columnas = 140 bits
%|       3.- COLUMNAS = columnas de la matriz de entrelazado
%|                   Valor por defecto: 10
%|                   Restricciones: filas x columnas = 140 bits% 
%|
%|    Salida:
%|       1.- PAQUETE  = vector fila con 140 bits entrelazados
%|                    
%-------------------------------------------------------------------------
%|   Autor: Cesar Delgado
%|   Fecha: 19-Abril-2.004
%-------------------------------------------------------------------------

%  1.- Asignacin valores por defecto
%-----------------------------------------
if nargin < 1,
   disp('ERROR: faltan parmetros en entrelaza()');
   return;
elseif nargin < 2,
   filas = 14;
   columnas = 10;
elseif nargin < 3,
   columnas = 10;
end;

if isempty(columnas), columnas = 10; end;
if isempty(filas), filas = 14; end;

   
% 2.- Entrelazado
%----------------
%   2.1.- Zero Padding hasta 140 bits si es necesario
lonDatos = length(datos);
if lonDatos<140,
   datos(140) = 0; 
end;

%   2.2.- Guardamos por columnas
for col = 1: columnas,
   aux(1:filas,col) = datos(1:filas)'; 
   datos(1:filas)   = [];   
end;

paquete = [];

%   2.3.- Leemos por filas
for fila = 1: filas,
   paquete = [paquete aux(fila,:)];
end;


   