function [CRC] = generaCRC (trama, tramo, codigo, metodo)
%------------------------------------------------------------------------
%|  function [CRC] = generaCRC (trama, tramo, codigo, metodo)
%------------------------------------------------------------------------
%|    Funcin que crea un cdigo de redundancia para 
%|  la correccin de errores.
%|
%|      NO REALIZA VALIDACIN DE PARMETROS (se implementa
%|          en la interfaz grfica)
%|
%|    Entradas:
%|       1.- TRAMA  = vector de ceros y unos (fila o columna)
%|                    Caso de ser matriz, se toma 1 columna traspuesta
%|       2.- TRAMO = la codificacion se aplica en tramos de (2^M)-1 bits
%|                   Restricciones    : TRAMO=(2^M)-1, M = 3,4,5,...
%|                                      TRAMO < length(TRAMA)
%|                   Valor por defecto: 7     
%|       3.- CODIGO = longitud de la palabra empleada para la codificacin
%|                   Restricciones    : CODIGO < TRAMO
%|                                      En Hamming: CODIGO = (2^M) - M
%|                   Valor por defecto: 4
%|       4.- METODO = tipo de cdigo de errores:
%|            4.1.- 'hamming': por el mtodo hamming => Valor por defecto
%|            4.2.- 'cyclic': cdigos de redundancia cclica
%|            4.3.- 'bch': cdigos de redundacia cclica interpretando
%|                         mensaje binario
%|            4.4.- 'rs': cdigos de Reed-Solomon
%|
%|    Salida:
%|       1.- CRC =  vector fila con la trama codificada.
%|                  Su longitud ser de length(TRAMA+1)*(TRAMO/CODIGO) 
%|                  o nula si algo ha ido mal (length(CRC)=0);
%|
%|     NOTA: requiere Toolbox de Comunicaciones
%-------------------------------------------------------------------------
%|   Autor: Cesar Delgado
%|   Fecha: 19-Abril-2.004
%-------------------------------------------------------------------------


% 1.- Generacion de codigos de redundancia
%-----------------------------------------
 CRC = encode(trama,tramo,codigo,metodo);
 CRC = CRC';
