function binario = TXTtoBinary(texto, ruta, nBits)

%------------------------------------------------------------------------
%| function binario = TXTtoBinary(texto, nBits)
%------------------------------------------------------------------------
%|    Funcin que realiza la traduccin de texto a binario. 
%|    Toma como entrada una cadena de caracteres y genera un
%| fichero de saluda llamado 'info.tx'.
%|
%|    Entradas:
%|       1.- TEXTO = vector fila con la cadena de caracteres a codificar 
%|       2.- RUTA = cadena de caracteres con la ruta 
%|                   donde guardar el fichero.
%|                   Valor por defecto: ''
%|       3.- N_BITS= nmero de bits a usar en la codificacin
%|                   Valor por defecto: 8
%| 
%-------------------------------------------------------------------------
%   Autor: Cesar Delgado
%   Fecha: 19-Abril-2.004
%-------------------------------------------------------------------------

%   1.- Validacin de parmetros
%-----------------------------------------------------------------

if nargin < 1,
   disp('ERROR: faltan parmetros en TXTtoBinary');
   return;
elseif isempty(texto),
   disp('ERROR: faltan parmetros en TXTtoBinary');
   return;
elseif nargin < 2,
   ruta = '';
   nBits = 8;
elseif nargin < 3
   nBits=8;
elseif isempty(nBits), 
   nBits=8; 
end;

%   2.- Transformamos de texto a cadena de caracteres de "0" y "1"
%-----------------------------------------------------------------
binario  = de2bi(double(texto),nBits);
filas    = size(binario,1);
columnas = size(binario,2);

%   3.- Construimos vector fila de  "0" y "1"
%-----------------------------------------------------------------
binario  = reshape(binario',1,filas*columnas);


%   4.- Guardamos dicha seal en fichero: 0 1 0 ...
%-----------------------------------------------------------------
guardar(ruta,'info.tx',binario,0,1);